Module optimization

Module optimization 

Optimization primitives over ndarray vectors.

Structs

AdamConfig
Configuration for Adam optimizer.
BFGSConfig
Configuration for BFGS quasi-Newton optimization.
LineSearchConfig
Configuration for backtracking line search.
MomentumConfig
Configuration for momentum gradient descent.
ProjectedGradientConfig
Configuration for projected gradient descent with box constraints.
RMSPropConfig
Configuration for RMSProp optimizer.
SGDConfig
Configuration for SGD.

Enums

OptimizationError
Error type for optimization routines.

Functions

adam
Minimize objective with Adam.
adam_complex
Minimize objective with complex Adam updates.
backtracking_line_search
Perform Armijo backtracking line search.
backtracking_line_search_complex
Perform Armijo backtracking line search for complex vectors.
bfgs
Minimize objective with BFGS quasi-Newton updates.
bfgs_complex
Minimize objective with complex BFGS quasi-Newton updates.
gradient_descent
Minimize objective with fixed-step gradient descent.
gradient_descent_complex
Minimize objective with fixed-step complex gradient descent.
momentum_descent
Minimize objective with momentum gradient descent.
momentum_descent_complex
Minimize objective with complex momentum gradient descent.
projected_gradient_descent_box
Minimize objective with projected gradient descent under box constraints.
projected_gradient_descent_box_complex
Minimize objective with complex projected gradient descent under box constraints.
rmsprop
Minimize objective with RMSProp.
rmsprop_complex
Minimize objective with complex RMSProp.
stochastic_gradient_descent
Minimize objective with stochastic gradient descent.
stochastic_gradient_descent_complex
Minimize objective with complex stochastic gradient descent.